@@ -893,7 +893,7 @@ class Agent(object):
 					print("kill output:",output)
 				except: a=1
 				try:
-					output = utils.__execute__script_(f"eval `ssh-agent`", shell=True)
+					output = utils.__execute_script__(f"eval `ssh-agent`", shell=True)
 					try: 
 						SSH_AUTH_SOCK = output.split("SSH_AUTH_SOCK=")[1].split(";")[0]
 						os.environ["SSH_AUTH_SOCK"] = SSH_AUTH_SOCK
